@@ -1,7 +1,7 @@
 package Hash::Subset;
 
 our $DATE = '2019-07-10'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use warnings;
@@ -12,39 +12,39 @@ our @EXPORT_OK = qw(hash_subset hashref_subset);
 sub hash_subset {
     my ($hash, $keys_src) = @_;
 
-    my %res;
+    my %subset;
     my $ref = ref $keys_src;
     if ($ref eq 'ARRAY') {
         for (@$keys_src) {
-            $res{$_} = $hash->{$_} if exists $hash->{$_};
+            $subset{$_} = $hash->{$_} if exists $hash->{$_};
         }
     } elsif ($ref eq 'HASH') {
         for (keys %$keys_src) {
-            $res{$_} = $hash->{$_} if exists $hash->{$_};
+            $subset{$_} = $hash->{$_} if exists $hash->{$_};
         }
     } else {
         die "Second argument (keys_src) must be a hashref/arrayref";
     }
-    %res;
+    %subset;
 }
 
 sub hashref_subset {
     my ($hash, $keys_src) = @_;
 
-    my $res = {};
+    my $subset = {};
     my $ref = ref $keys_src;
     if ($ref eq 'ARRAY') {
         for (@$keys_src) {
-            $res->{$_} = $hash->{$_} if exists $hash->{$_};
+            $subset->{$_} = $hash->{$_} if exists $hash->{$_};
         }
     } elsif ($ref eq 'HASH') {
         for (keys %$keys_src) {
-            $res->{$_} = $hash->{$_} if exists $hash->{$_};
+            $subset->{$_} = $hash->{$_} if exists $hash->{$_};
         }
     } else {
         die "Second argument (keys_src) must be a hashref/arrayref";
     }
-    $res;
+    $subset;
 }
 
 1;
@@ -62,19 +62,19 @@ Hash::Subset - Produce subset of a hash
 
 =head1 VERSION
 
-This document describes version 0.001 of Hash::Subset (from Perl distribution Hash-Subset), released on 2019-07-10.
+This document describes version 0.002 of Hash::Subset (from Perl distribution Hash-Subset), released on 2019-07-10.
 
 =head1 SYNOPSIS
 
  use Hash::Subset qw(hash_subset hashref_subset);
 
- # using keys specified from an array
- my %h = hash_subset   ({a=>1, b=>2, c=>3}, ['b','c','d']); # => (b=>2, c=>3)
- my $h = hashref_subset({a=>1, b=>2, c=>3}, ['b','c','d']); # => {b=>2, c=>3}
+ # using keys specified in an array
+ my %subset = hash_subset   ({a=>1, b=>2, c=>3}, ['b','c','d']); # => (b=>2, c=>3)
+ my $subset = hashref_subset({a=>1, b=>2, c=>3}, ['b','c','d']); # => {b=>2, c=>3}
 
- # using keys specified from another hash
- my %h = hash_subset   ({a=>1, b=>2, c=>3}, {b=>20, c=>30, d=>40}); # => (b=>2, c=>3)
- my $h = hashref_subset({a=>1, b=>2, c=>3}, {b=>20, c=>30, d=>40}); # => {b=>2, c=>3}
+ # using keys specified in another hash
+ my %subset = hash_subset   ({a=>1, b=>2, c=>3}, {b=>20, c=>30, d=>40}); # => (b=>2, c=>3)
+ my $subset = hashref_subset({a=>1, b=>2, c=>3}, {b=>20, c=>30, d=>40}); # => {b=>2, c=>3}
 
 =head1 DESCRIPTION
 
@@ -86,14 +86,32 @@ None exported by default.
 
 Usage:
 
- my %hash    = hash_subset   (\%hash, \@keys);
- my $hashref = hashref_subset(\%hash, \@keys);
- my %hash    = hash_subset   (\%hash, \%another_hash);
- my $hashref = hashref_subset(\%hash, \%another_hash);
+ my %subset  = hash_subset   (\%hash, \@keys);
+ my $subset  = hashref_subset(\%hash, \@keys);
+ my %subset  = hash_subset   (\%hash, \%another_hash);
+ my $subset  = hashref_subset(\%hash, \%another_hash);
 
 Produce subset of C<%hash>, returning the subset hash (or hashref, in the case
 of C<hashref_subset> function).
 
+Perl lets you produce a hashref using the slice notation:
+
+ my %subset = %hash{"b","c","d"};
+
+The difference with this routine is: 1) hash slice is only available since perl
+5.20 (in previous versions, only array slices is available); 2) when the key
+does not exist in the array, perl will create it for you with C<undef> as the
+value, so:
+
+ my %hash   = (a=>1, b=>2, c=>3);
+ my %subset = %hash{"b","c","d"}; # => (b=>2, c=>3, d=>undef)
+
+So basically C<hash_subset> is equivalent to:
+
+ my %subset = %hash{grep {exists $hash{$_}} "b","c","d"}; # => (b=>2, c=>3, d=>undef)
+
+and available for perl earlier than 5.20.
+
 =head2 hashref_subset
 
 See L</hash_subset>.
